.. rst-class:: detail

ReadGroup
====================

.. currentmodule:: compas_rrc

.. autoclass:: ReadGroup

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ReadGroup.__init__
        ~ReadGroup.from_msg
        ~ReadGroup.parse_feedback
    
    